@@ -117,7 +117,8 @@ class MapLoader(object):
                     if "REMARK 900 RELATED ID:" in line and "EMD-" in line and not found_em:
                         found_em=True
                         info = line.split(" ")
-                        self.em_code = info[4]
+                        self.mobj.em_code = info[4]
+                        self.em_code = self.mobj.em_code
                         self.has_both = False
                         self.mobj.em_link = f"https://www.ebi.ac.uk/emdb/{self.em_code}"
                 
@@ -170,6 +171,7 @@ class MapLoader(object):
         if not exists(self._filepath_diff):            
             urllib.request.urlretrieve(self.mobj.diff_link, self._filepath_diff)
         self.mobj.em_code = self.mobj.pdb_code
+        self.em_code = self.mobj.pdb_code
 
                         
     def _fetch_maplink_em(self):     
